@@ -14,7 +14,7 @@ use Scope::Guard;
 
 use Exporter qw(import);
 
-our $VERSION = '0.20_01';
+our $VERSION = '0.20_02';
 our @EXPORT_OK = qw(start_server restart_server server_ports);
 
 my @signals_received;
@@ -406,7 +406,7 @@ sub _wait3 {
                 if $sighandler_got_sig;
             $pid = wait();
         };
-        if (! defined $pid && $@) {
+        if ($pid == -1 && $@) {
             $! = Errno::EINTR;
         }
     } else {
